@@ -10,4 +10,7 @@ from firstimpression import constants
 
 from os.path import join
 
-file.create_directories([join(constants.LOCAL_INTEGRATED_FOLDER, api_name) for api_name in constants.APIS])
+file.create_directories(
+    [join(constants.LOCAL_INTEGRATED_FOLDER, api_name) for api_name in constants.APIS])
+file.create_directories([join(constants.TEMP_FOLDER, api_name)
+                        for api_name in constants.APIS])
