@@ -1,5 +1,5 @@
-from firstimpression.api import request_json
-from firstimpression.time import parse_string_to_date, parse_string_time_to_minutes
+from firstimpression.api.request import request_json
+from firstimpression.time import parse_string_to_date, parse_string_time_to_minutes, parse_date_to_string
 
 
 def get_response(url, headers, params):
@@ -8,6 +8,8 @@ def get_response(url, headers, params):
     if response_json.get('statusCode', None) == 429:
         raise Exception('Rate limit exceeded')
 
+    return response_json
+
 
 def get_departures(response_json):
     return response_json['payload']['departures']
@@ -82,7 +84,7 @@ def get_message(departure):
     return msg
 
 
-def get_parsed_departures(response_json):
+def get_parsed_departures(response_json, date_format):
     departures = get_departures(response_json)
     parsed_departures = list()
     for departure in departures:
@@ -95,7 +97,7 @@ def get_parsed_departures(response_json):
         parsed_departure['operator'] = get_operator(departure)
         parsed_departure['planned_track'] = get_planned_track(departure)
         parsed_departure['actual_track'] = get_actual_track(departure)
-        parsed_departure['delay'] = get_delay(departure)
+        parsed_departure['delay'] = get_delay(departure, date_format)
         parsed_departure['message'] = get_message(departure)
         parsed_departures.append(parsed_departure)
 
